==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/gme/translations/gme_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="38"/>
        <source>GME Plugin</source>
        <translation>Модуль GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="41"/>
        <source>Game Music Files</source>
        <translation>Программы звукогенераторов</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="103"/>
        <source>About GME Audio Plugin</source>
        <translation>Об аудио-модуле GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="104"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Аудио-модуль GME для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="105"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Для воспроизведения используется библиотека Game_Music_Emu </translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Настройки модуля GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Длительность затухания:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>мс</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Включить затухание</translation>
    </message>
</context>
</TS>

==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/gme/translations/gme_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="50"/>
        <source>GME Plugin</source>
        <translation>Модуль GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="53"/>
        <source>Game Music Files</source>
        <translation>Программы звукогенераторов</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>About GME Audio Plugin</source>
        <translation>Об аудио-модуле GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Аудио-модуль GME для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Для воспроизведения используется библиотека Game_Music_Emu </translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="120"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Настройки модуля GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Длительность затухания:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>мс</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Включить затухание</translation>
    </message>
</context>
</TS>
